@@ -830,10 +830,18 @@ impl<'repo> StackTransaction<'repo> {
             panic!("old `{old_patchname}` not found in applied, unapplied, or hidden");
         }
 
-        let patch = self.stack.get_patch(old_patchname).clone();
-        self.updated_patches.insert(old_patchname.clone(), None);
-        self.updated_patches
-            .insert(new_patchname.clone(), Some(patch));
+        if let Some(Some(patch_state)) = self.updated_patches.remove(old_patchname) {
+            // The renamed patch may have been previously updated in this transaction.
+            // This can happen, for example, for `stg refresh`.
+            self.updated_patches.insert(old_patchname.clone(), None);
+            self.updated_patches
+                .insert(new_patchname.clone(), Some(patch_state));
+        } else {
+            let patch_state = self.stack.get_patch(old_patchname).clone();
+            self.updated_patches.insert(old_patchname.clone(), None);
+            self.updated_patches
+                .insert(new_patchname.clone(), Some(patch_state));
+        }
 
         self.ui.print_rename(old_patchname, new_patchname)
     }
